# ~/.cshrc --
if ( ! $?prompt ) then 
  # non-interactive? bail out...
  exit
endif

#echo enter .cshrc, arg0=$0, SHLVL=$SHLVL
if ( "$0" == '-tcsh' || "$0" == '-csh' ) then
	# echo passed -csh test
	source /etc/csh.login
	source $HOME/.login
else
    # for FC 4
    #if ( $SHLVL == 3 ) then
	# with KDE on Fedora and their xdm, we end up without -cshrc, but with


    # for FC 8
#    if ( $SHLVL <= 1 ) then
#	# with Gnome on Fedora8 and gdm, we end up without -cshrc, but with
#	# echo TOP level shell
#	source /etc/csh.login
#	source $HOME/.login
#    endif
endif
# end of top level shell detection


set path = ( ~/bin /usr/local/bin /bin /usr/bin /opt/bin )
eval `addpath -sx /usr/X11R6/bin`
eval `addpath -sx /usr/openwin/bin`

if ( $?PATH_PREFIX ) then
 set path = ( $PATH_PREFIX $path )
endif

eval `addpath -s '$ORACLE_HOME/bin' `
eval `addpath -s '$ACCUREV_BIN' `
eval `addpath -s '$JAVA_HOME/bin' `
eval `addpath -s '$ANT_HOME/bin' `
eval `addpath -s '$MONO_HOME/bin' `
eval `addpath -s '$FORREST_HOME/bin' `
eval `addpath -sfx '/usr/gnat/bin' `

if ( $?QTDIR ) then
	eval `addpath -sx '$QTDIR/bin' `
	setenv MANPATH `addpath -bx -p MANPATH '$QTDIR/doc/man'`
	setenv LD_LIBRARY_PATH `addpath -bfx -p LD_LIBRARY_PATH '$QTDIR/lib'`
endif

if ( $?CDPATH ) then
	set cdpath = ( `echo $CDPATH | tr : ' ' ` )
else
	set cdpath = ( ~ /bfs/snapshot /bfs/builds/ia32-linux-2.6 )
endif
if ( $?ACCUREV_TOPDIR ) then
	set cdpath = ( $ACCUREV_TOPDIR $cdpath )
endif

set history=100
if ( $uid == 0 ) then
	set prompt='%n@%m:%c2% # ' 
	set prompt='%m:%c2 \!# ' 
else
	set prompt='%m:%c2 \!% ' 
endif
if ( $?prompt_context ) then
	set prompt="${prompt_context}_$prompt"
endif

# 2 really means top level on FC 8 w/ gdm
set pr_prefix = ( '' '._' '.._' '..._' '...._' '....._' '.>>>._' )
if ( $SHLVL < 8 ) then
	set prompt="${pr_prefix[$SHLVL]}$prompt"
else
	set prompt="${pr_prefix[8]}$prompt"
endif
unset pr_prefix


if ( $?ACCUREV_BIN ) then
	alias ac $ACCUREV_BIN/accurev
endif
alias mozilla firebird

alias achelp SHOWHTML /ICS/Software/accurev/doc/ref/accurev.html 
alias h history
alias j jobs -l
alias l ls -Fax
alias ll ls -Alg
alias ldpath 'setenv LD_LIBRARY_PATH `addpath -bfp LD_LIBRARY_PATH \!^`'
alias addcp 'setenv CLASSPATH `addpath -bf -p CLASSPATH \!^`'
alias pd pushd
alias z suspend
alias dir /bin/ls -la
alias mroe more
alias term xterm -fn 12x24
alias G getpun frito tony@ics.com xyzzy
alias GI getpun pup.popupnotes.com tony@ics.com xyzzy
alias sql sqlplus pun/qwert@PUNC
alias MDK priv /usr/sbin/chroot /old/root su - tony
alias thunderbird /home/tony/tools/thunderbird/thunderbird

alias tgrep 'find . -type f -print0 | xargs -0 grep'

alias trc 'xterm -fn 8x13 -geometry 154x20+0-0 -e priv /root/bin/TRC &'
alias logs 'xterm -fn 12x24 -e ssh -l logs src.dev.popupnotes.com &'

bindkey "^B" backward-word
bindkey "^?" delete-char


alias termwp 'xterm -fn 12x24 -e ssh www.popupnotes.com &'
alias termpp 'xterm -fn 12x24 -e ssh pup.popupnotes.com &'
alias termdbase 'xterm -fn 12x24 -e ssh db2 &'
alias termwd 'xterm -fn 12x24 -e ssh www.dev.popupnotes.com &'
alias termpd 'xterm -fn 12x24 -e ssh pup.dev.popupnotes.com &'
alias termdd 'xterm -fn 12x24 -e ssh dbase.popupnotes.com &'
alias termsrc 'xterm -fn 12x24 -e ssh src.dev.popupnotes.com &'
alias ronin 'xterm -fn 12x24 -e ssh ronin.ics.com &'
alias samurai 'xterm -fn 12x24 -sb -name Samurai -e ssh samurai.ics.com &'
alias radiskull 'xterm -fn 12x24 -e ssh radiskull.ics.com &'

#alias deckard 'xterm -fn 12x24 -sb -name deckard -e ssh samurai.ics.com "/usr/ucb/rlogin deckard" &'
alias deckard 'xterm -fn 12x24 -sb -name deckard -e rlogin deckard &'
#alias rattle 'xterm -fn 12x24 -sb -name rattle -e ssh samurai.ics.com "/usr/ucb/rlogin rattle" &'
#alias sunoco 'xterm -fn 12x24 -sb -name sunoco -e ssh samurai.ics.com "/usr/ucb/rlogin sunoco" &'
alias rattle 'xterm -fn 12x24 -sb -name rattle -e telnet 216.112.183.156 &'
alias sunoco 'xterm -fn 12x24 -sb -name sunoco -e telnet 216.112.183.142 &'

alias india 'xterm -fn 12x24 -sb -name india -e ssh india.ics.com &'
alias ftpics 'xterm -fn 12x24 -sb -name ftp.ics.com -e ssh -i ~/.ssh/mrzippy ftp.ics.com &'

alias il 'xterm -fn 12x24 -e ssh -x -i $HOME/.ssh/id4 usr223125024@66.223.125.24 &'
alias oh 'xterm -fn 12x24 -e ssh -x -i $HOME/.ssh/id4 aiuto@www.toastman.net &'
alias pixie 'xterm -fn 12x24 -sb -name pixie -e ssh pixie &'

alias hp 'xterm -fn 12x24 -sb -name HP -e rlogin hpdev1 &'
alias ga 'xterm -fn 12x24 -sb -name greenwich -e ssh -Y ga & '

alias qt321 source ~/bin/qt321.csh

alias qt322 source ~/bin/qt322.csh
alias magnify '/usr/local/bin/lupe -mag 2 -noshape -nohud -geometry 600x300'

alias fi ~/AGM/agm_recon/bin/findInclude
alias fr ~/AGM/agm_recon/bin/findRecon
alias fl ~/AGM/agm_recon/bin/fl

set filec
# this should not really have to be here, but I keep it as a talisman
set term=vt100
stty erase ''

# ODE setup
if ( $?BCSSET ) then
	set path = ( $HOME/bin/ode $path )
endif

# override choices made by Fedora /etc/csh.cshrc
unalias precmd
unalias jobcmd
#echo end of .cshrc
